/* Democracy - a Bukkit plugin bringing voting features to Minecraft Servers
 * Copyright (c) 2011 Ed Halley <ed@halley.cc>
 * Offered under the MIT License.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package cc.halley.bukkit.Democracy;

import org.bukkit.ChatColor;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

public class DemocracyEnactCommand
    implements CommandExecutor
{
	private Democracy democracy = null;

	public DemocracyEnactCommand(Democracy democracy)
		{ this.democracy = democracy; }

	public boolean onHelp(CommandSender sender)
	{
		sender.sendMessage(ChatColor.GRAY + "usage: /enact <issue> [<reason>]");
		return true;
	}

	@Override
	public boolean onCommand(CommandSender sender, Command command,
	                         String label, String[] args)
	{
    	democracy.checkIssuesDue();

		boolean enactment = true;
		if (label.equalsIgnoreCase("veto"))
		{
			if (!Democracy.config.getBoolean("voting.allow-vetoes", true))
			{
				sender.sendMessage(ChatColor.RED +
				                   "Vetoes are not allowed.");
				return true;
			}
			enactment = false;
		}

		int argp = 0;
		if (argp >= args.length)
			return false;

		// Console users can't enact or veto?
		if (!(sender instanceof Player) &&
			!Democracy.config.getBoolean("voting.allow-console-enact-veto",
			                             true))
		{
			Democracy.log.warning("Only logged-in players can enact proposals.");
			return true;
		}

		// Name
		String name = args[argp++];
		
		if (name.equalsIgnoreCase("help"))
			return onHelp(sender);

		DemocracyIssue issue = democracy.findIssue(name);
		if (issue == null)
		{
			sender.sendMessage(ChatColor.RED +
			                   "Cannot find that proposal to " +
			                   (enactment? "enact" : "veto") + ".");
			return true;
		}

		if (issue.isUnopened())
		{
			sender.sendMessage(ChatColor.RED +
			                   "Cannot " +
			                   (enactment? "enact" : "veto") +
			                   " a proposal that is not yet open.");
			return true;
		}
		
		if (enactment && !issue.isExpired())
		{
			String remain =
				issue.summarizeDuration(issue.expires - System.currentTimeMillis());
			sender.sendMessage(ChatColor.RED +
			                   "Cannot enact a proposal that's still open. " +
			                   "Time remaining: " + remain + ".");
			return true;
		}

		String reason = null;
		StringBuilder sb = new StringBuilder();
		while (argp < args.length)
		{
			sb.append(issue.description); issue.description = " ";
			sb.append(args[argp++]);
		}
		reason = sb.toString();

		// Didn't think the command "enact" would really do anything? Did you?
		// This just removes the completed vote issue from the system.
		// Doing whatever they voted for... that's the enactors.
		//
		democracy.announceAction(issue, sender, enactment, reason);
		democracy.removeIssue(issue);

		//TODO: look into Bukkit.dispatchCommand(sender, command)...
		
		return true;
	}
}
