/* Democracy - a Bukkit plugin bringing voting features to Minecraft Servers
 * Copyright (c) 2011 Ed Halley <ed@halley.cc>
 * Offered under the MIT License.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package cc.halley.bukkit.Democracy;

import cc.halley.kata.S;

import org.bukkit.ChatColor;
import org.bukkit.entity.Player;
import org.bukkit.event.player.PlayerJoinEvent;
import org.bukkit.event.player.PlayerListener;

public class DemocracyPlayerListener
    extends PlayerListener
{
	private final Democracy plugin;

	public DemocracyPlayerListener(Democracy democracy)
	{
		plugin = democracy;
	}

	@Override
	public void onPlayerJoin(PlayerJoinEvent event)
	{
		summarizePlayerIssues(event.getPlayer());
	}

	public void summarizePlayerIssues(Player player)
	{
		// Check for open issues she's eligible to vote. Let him know.
		if (player.hasPermission("democracy.vote.cast"))
		{
			int n = plugin.countVotableIssues(player);
			if (n > 0)
			    player.sendMessage(ChatColor.GRAY +
			        "There " + S.plural(n, "is", "are") +
			        " " + n + S.plural(n, " proposal", " proposals") +
			        " open for a vote. See /vote for more.");
		}

		// Check for resolved issues she may need to enact or want to know.
		if (player.hasPermission("democracy.vote.tally"))
		{
			int n = plugin.countResolvedIssues();
			if (n > 0)
			    player.sendMessage(ChatColor.GRAY +
			        "There " + S.plural(n, "is", "are") +
			        " " + n + S.plural(n, " proposal", " proposals") +
			        " now resolved. See /tally for more.");
		}
	}
}
